# Geometry Arrays

The classes on this page represent arrays of geospatial geometries.

- [`PointArray`](#geoarrow.rust.core.PointArray)
- [`LineStringArray`](#geoarrow.rust.core.LineStringArray)
- [`PolygonArray`](#geoarrow.rust.core.PolygonArray)
- [`MultiPointArray`](#geoarrow.rust.core.MultiPointArray)
- [`MultiLineStringArray`](#geoarrow.rust.core.MultiLineStringArray)
- [`MultiPolygonArray`](#geoarrow.rust.core.MultiPolygonArray)
- [`MixedGeometryArray`](#geoarrow.rust.core.MixedGeometryArray)
- [`GeometryCollectionArray`](#geoarrow.rust.core.GeometryCollectionArray)
- [`WKBArray`](#geoarrow.rust.core.WKBArray)
- [`RectArray`](#geoarrow.rust.core.RectArray)

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
        - "^__arrow"
      members:
        - PointArray
        - LineStringArray
        - PolygonArray
        - MultiPointArray
        - MultiLineStringArray
        - MultiPolygonArray
        - MixedGeometryArray
        - GeometryCollectionArray
        - WKBArray
        - RectArray
